@@ -592,9 +592,15 @@ class Generator_Stochastic(Generator_nonControllable):
     def _get_scenario_values(self, times, s=0):
         # scenario values are structured as a pd.Panel
         # with axes: day, scenario, {prob, [hours]}
-        return self.scenario_values[times.Start][
-            range(len(times))].ix[s].values.tolist()
-
+        # the panel has items which are dates 
+        return self.scenario_values[times.Start.date()][
+            range(len(times))].ix[s].dropna().values.tolist()
+    
+    def _get_scenario_probabilities(self, times):
+        # if any of the scenario values are defined, we want them
+        return self.scenario_values[
+            times.Start.date()].dropna(how='all').probability
+    
     def create_variables(self, times):
         if self.shedding_mode:
             self.create_variables_shedding(times)
